#
# spec file for package python-django-extensions
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-django-extensions
Version:        2.2.9
Release:        bp153.1.23
Summary:        Extensions for Django
License:        BSD-3-Clause
URL:            https://github.com/django-extensions/django-extensions
Source:         https://github.com/django-extensions/django-extensions/archive/%{version}.tar.gz#/django-extensions-%{version}.tar.gz
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module django-json-widget}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module factory_boy}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module shortuuid}
BuildRequires:  %{python_module six >= 1.2}
BuildRequires:  %{python_module typing}
BuildRequires:  %{python_module vobject}
BuildRequires:  fdupes
Requires:       python-Django
Requires:       python-six >= 1.2
Recommends:     python-Pygments
Recommends:     python-Werkzeug
Recommends:     python-django-json-widget
Recommends:     python-djangorestframework
Recommends:     python-python-dateutil
Suggests:       python-pip
Suggests:       python-python-dateutil
Suggests:       python-shortuuid
BuildArch:      noarch
%python_subpackages

%description
Django-extensions bundles several useful
additions for Django projects. See the project page for more information:
http://github.com/django-extensions/django-extensions

%prep
%setup -q -n django-extensions-%{version}

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
export DJANGO_SETTINGS_MODULE=tests.testapp.settings
# Test collection exception ValueError: wrapper loop when unwrapping call
# test_should_highlight_python_syntax_with_name - breaks ordering on py versions, fragile 
%python_expand $python -m pytest -v \
    --ignore tests/test_logging_filters.py \
    --ignore tests/management/commands/test_reset_db.py \
    --ignore tests/management/commands/test_reset_schema.py \
    --ignore tests/management/commands/test_pipchecker.py \
    -k 'not test_should_highlight_python_syntax_with_name'

%files %{python_files}
%license LICENSE
%doc README.rst docs/*.*
%{python_sitelib}/*

%changelog
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.9:
  * Fix: shell_plus, move notebook down the list of prefered shells
  * Fix: sqldiff, fix KeyError when detecting missing (unique) indexes
  * Improvement: encrypted fields, make it harder to use deprecated keyczar fields
  * Locale: Removed empty localizations
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.8:
  * Various small fixes
* Mon Jan 13 2020 pgajdos@suse.com
- fix build in SLE-15: set en_US.UTF-8 encoding
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.5:
  * RandomCharField, Support unique_together
  * export_emails, add settings for overriding queryset fields, order_by and the full_name function
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.3:
  * minor fixes
- Disable py2 package due to unsattisfied dependencies
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.1:
  * More tests
  * Many bugfixes
  * Fixes for newest pytest/django
* Fri Sep 13 2019 John Vandenberg <jayvdb@gmail.com>
- Use have/skip_python2/3 macros to allow building only one package
* Tue Mar 12 2019 John Vandenberg <jayvdb@gmail.com>
- Activate the test suite
- Add missing Requires python-six
- Add Recommends and Suggests
- Add fdupes
- Update to v2.1.6
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Use single spec style
- Use %%license
- Add missing Requires python-Django
- Update to v2.1.5
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 1.2.2
  + No changelog available
- Use download url as source
- Copy documentation from tarball
* Sun Jan 27 2013 alexandre@exatati.com.br
- Update to 1.0.3:
  - Sorry, no changelog atm.
* Mon Dec 17 2012 alexandre@exatati.com.br
- Update to 1.0.2:
  - Sorry, no changelog atm.
* Thu Nov  8 2012 alexandre@exatati.com.br
- Update to 1.0.1:
  - Sorry, no changelog atm.
* Mon Oct 22 2012 alexandre@exatati.com.br
- Update to 1.0.0:
  - Sorry, no changelog atm.
* Fri Jun  8 2012 alexandre@exatati.com.br
- Update to 0.9:
  - Sorry, no changelog atm.
* Mon Feb 27 2012 alexandre@exatati.com.br
- Update to 0.8:
  - Sorry, no changelog atm.
* Mon Oct 17 2011 alexandre@exatati.com.br
- Update to 0.7.1:
  - Sorry, no changelog atm.
- Regenerate spec file with py2pack;
- Bzip2 source code.
* Fri Apr 23 2010 alexandre@exatati.com.br
- Update to 0.5;
- Spec file cleaned with spec-cleaner;
- Building as noarch for openSUSE >= 11.2;
- Fixed Author, Description, Summary and URL tags in spec file.
